@@ -3,11 +3,6 @@ import importlib
 
 from lesscode.db.base_connection_pool import BaseConnectionPool
 
-try:
-    neo4j = importlib.import_module("neo4j")
-except ImportError as e:
-    raise Exception(f"neo4j is not exist,run:pip install neo4j==5.0.0")
-
 
 class Neo4jPool(BaseConnectionPool):
     """
@@ -19,6 +14,10 @@ class Neo4jPool(BaseConnectionPool):
         创建Neo4j 连接池
         :return:
         """
+        try:
+            neo4j = importlib.import_module("neo4j")
+        except ImportError:
+            raise Exception(f"neo4j is not exist,run:pip install neo4j==5.0.0")
         driver = neo4j.AsyncGraphDatabase.driver(f"bolt://{self.conn_info.host}:{self.conn_info.port}",
                                                  auth=(self.conn_info.user, self.conn_info.password))
         return driver
@@ -28,6 +27,10 @@ class Neo4jPool(BaseConnectionPool):
         创建Neo4j 连接池
         :return:
         """
+        try:
+            neo4j = importlib.import_module("neo4j")
+        except ImportError:
+            raise Exception(f"neo4j is not exist,run:pip install neo4j==5.0.0")
         driver = neo4j.GraphDatabase.driver(f"bolt://{self.conn_info.host}:{self.conn_info.port}",
                                             auth=(self.conn_info.user, self.conn_info.password))
         return driver
