@@ -16,6 +16,7 @@ from tornado.options import options, define
 
 from lesscode.db.init_connection_pool import InitConnectionPool
 from lesscode.extend_handlers.not_found_handler import NotFoundHandler
+from lesscode.sentry.sentry_monitor import sentry_monitor
 from lesscode.web.router_mapping import RouterMapping
 
 define("application_name", default=f"{os.path.split(os.path.abspath(os.path.dirname(sys.argv[0])))[-1]}", type=str,
@@ -53,6 +54,7 @@ define("cache_conn", default="redis_con_1", type=str, help="redis缓存连接")
 define("cache_enable", default=False, type=bool, help="redis缓存开关")
 define("task_list", default=[], type=list, help="任务列表")
 define("correction_param", default={"enable": False}, type=dict, help="aes加密key")
+define("sentry_config", default={"enable": False}, type=dict, help="sentry配置")
 # 日志初始化配置，配置文件中可修改设置
 options.logging = "DEBUG"
 options.log_rotate_mode = "time"
@@ -149,6 +151,7 @@ class WebServer:
         logging.info(f"start server : {options.application_name}")
         logging.info(f"start server port : {options.port}")
         try:
+            sentry_monitor()
             tornado.ioloop.IOLoop.current().start()
         except KeyboardInterrupt:
             pass
